@@ -14,6 +14,7 @@ const ONE: [&str; 1] = ["Apples"];
 const TWO: [&str; 2] = ["Apples", "Bananas"];
 const THREE: [&str; 3] = ["Apples", "Bananas", "Oranges"];
 const FIVE: [&str; 5] = ["Apples", "Bananas", "Oranges", "Pears", "Jackfruit"];
+const SLICE: &[&str] = &["Apples", "Bananas", "Oranges", "Pears", "Jackfruit"];
 
 
 
@@ -28,5 +29,8 @@ benches!(
 		.with(|| THREE.oxford_and()),
 
 	Bench::new("oxford_and", "([T; 5])")
-		.with(|| FIVE.oxford_and())
+		.with(|| FIVE.oxford_and()),
+
+	Bench::new("oxford_and", "(&[T])")
+		.with(|| SLICE.oxford_and())
 );
